summaryrefslogtreecommitdiff
path: root/indra/newview/llinventoryfilter.h
diff options
context:
space:
mode:
Diffstat (limited to 'indra/newview/llinventoryfilter.h')
-rw-r--r--indra/newview/llinventoryfilter.h24
1 files changed, 16 insertions, 8 deletions
diff --git a/indra/newview/llinventoryfilter.h b/indra/newview/llinventoryfilter.h
index d65fb8f27c..5ca77cb26a 100644
--- a/indra/newview/llinventoryfilter.h
+++ b/indra/newview/llinventoryfilter.h
@@ -61,7 +61,8 @@ public:
FILTERTYPE_NONE = 0,
FILTERTYPE_OBJECT = 1, // normal default search-by-object-type
FILTERTYPE_CATEGORY = 2, // search by folder type
- FILTERTYPE_UUID = 4 // find the object with UUID and any links to it
+ FILTERTYPE_UUID = 4, // find the object with UUID and any links to it
+ FILTERTYPE_DATE = 8 // search by date range
};
// REFACTOR: Change this to an enum.
@@ -73,13 +74,6 @@ public:
virtual ~LLInventoryFilter();
// +-------------------------------------------------------------------+
- // + Execution And Results
- // +-------------------------------------------------------------------+
- BOOL check(const LLFolderViewItem* item);
- BOOL checkAgainstFilterType(const LLFolderViewItem* item);
- std::string::size_type getStringMatchOffset() const;
-
- // +-------------------------------------------------------------------+
// + Parameters
// +-------------------------------------------------------------------+
void setFilterObjectTypes(U64 types);
@@ -103,12 +97,25 @@ public:
void setHoursAgo(U32 hours);
U32 getHoursAgo() const;
+ // +-------------------------------------------------------------------+
+ // + Execution And Results
+ // +-------------------------------------------------------------------+
+ BOOL check(const LLFolderViewItem* item);
+ BOOL checkAgainstFilterType(const LLFolderViewItem* item);
+ std::string::size_type getStringMatchOffset() const;
+
+ // +-------------------------------------------------------------------+
+ // + Presentation
+ // +-------------------------------------------------------------------+
void setShowFolderState( EFolderShow state);
EFolderShow getShowFolderState() const;
void setSortOrder(U32 order);
U32 getSortOrder() const;
+ void setEmptyLookupMessage(const std::string& message);
+ const std::string& getEmptyLookupMessage() const;
+
// +-------------------------------------------------------------------+
// + Status
// +-------------------------------------------------------------------+
@@ -187,6 +194,7 @@ private:
BOOL mModified;
BOOL mNeedTextRebuild;
std::string mFilterText;
+ std::string mEmptyLookupMessage;
};
#endif